package com.cnbm.basic.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.cnbm.basic.dto.ProductFeaturesHisDTO;
import com.cnbm.basic.entity.ProductFeaturesHis;
import com.cnbm.common.page.PageData;
import com.cnbm.common.service.impl.CrudServiceImpl;
import com.cnbm.basic.dto.ProductFeaturesDTO;
import com.cnbm.basic.mapper.ProductFeaturesMapper;
import com.cnbm.basic.entity.ProductFeatures;
import com.cnbm.basic.service.IProductFeaturesService;
import com.cnbm.common.utils.ConvertUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Map;

/**
 * 产品特性 表
 *
 * @author why
 * @since 2022-07-15
 */
@Service
public class ProductFeaturesServiceImpl extends CrudServiceImpl<ProductFeaturesMapper, ProductFeatures, ProductFeaturesDTO> implements IProductFeaturesService {

    @Override
    public QueryWrapper<ProductFeatures> getWrapper(Map<String, Object> params){
        String id = (String)params.get("id");

        QueryWrapper<ProductFeatures> wrapper = new QueryWrapper<>();
        wrapper.eq(StringUtils.isNotBlank(id), "id", id);

        return wrapper;
    }

    @Override
    public PageData<ProductFeaturesDTO> page (Map<String, Object> params){
        IPage<ProductFeatures> page = baseDao.selectPage(
                getPage(params, "id", true),
                getWrapper(params)
        );
        return getPageData(page, ProductFeaturesDTO.class);
    }

    @Override
    public ProductFeaturesDTO get(Long id) {
        ProductFeatures entity = baseDao.selectById(id);
        return ConvertUtils.sourceToTarget(entity, ProductFeaturesDTO.class);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void save(ProductFeaturesDTO dto) {
        ProductFeatures entity = ConvertUtils.sourceToTarget(dto, ProductFeatures.class);
        insert(entity);
    }

    @Autowired
    private ProductFeaturesHisServiceImpl productFeaturesHisServiceImpl;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void update(ProductFeaturesDTO dto) {
        //当产品特性出现update的时候，就会把旧数据 全量备份到这张表
        ProductFeatures oentity = baseDao.selectById(dto.getId());
        ProductFeaturesHisDTO history = ConvertUtils.sourceToTarget(oentity, ProductFeaturesHisDTO.class);
        history.setProductFeaturesId(oentity.getId());
        history.setId(null);
        productFeaturesHisServiceImpl.save(history);
        //更新
        ProductFeatures entity = ConvertUtils.sourceToTarget(dto, ProductFeatures.class);
        updateById(entity);

    }

}