package com.cnbm.basic.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.cnbm.basic.entity.ProductType;
import com.cnbm.common.page.PageData;
import com.cnbm.common.service.impl.CrudServiceImpl;
import com.cnbm.basic.dto.ProductDTO;
import com.cnbm.basic.mapper.ProductMapper;
import com.cnbm.basic.entity.Product;
import com.cnbm.basic.service.IProductService;
import com.cnbm.common.utils.ConvertUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.Map;

/**
 * 产品 表
 *
 * @author why
 * @since 2022-07-11
 */
@Service
public class ProductServiceImpl extends CrudServiceImpl<ProductMapper, Product, ProductDTO> implements IProductService {

    //@Autowired
    //ProductMapper mapper;

    @Override
    public QueryWrapper<Product> getWrapper(Map<String, Object> params){
        String name = (String)params.get("name");
        String code = (String)params.get("code");
        //检验阶段
        String inspection_stage = (String)params.get("inspection_stage");

        QueryWrapper<Product> wrapper = new QueryWrapper<>();
        wrapper.like(StringUtils.isNotBlank(name), "name", name);
        wrapper.like(StringUtils.isNotBlank(code), "code", code);
        wrapper.eq(ObjectUtils.isNotNull(params.get("status")), "status", params.get("status"));
        wrapper.eq(ObjectUtils.isNotNull(params.get("product_type_id")), "product_type_id", params.get("product_type_id"));
        wrapper.eq(StringUtils.isNotBlank(inspection_stage), "inspection_stage", inspection_stage);
        return wrapper;
    }

    @Autowired
    private ProductTypeServiceImpl productTypeService;

    @Override
    public PageData<ProductDTO> page (Map<String, Object> params){
        //IPage<ProductDTO> page = mapper.page(params);
        //return getPageData(page, ProductDTO.class);
        IPage<Product> page = baseDao.selectPage(
                getPage(params, "id", true),
                getWrapper(params)
        );
        PageData<ProductDTO> productDTOPageData = getPageData(page,ProductDTO.class);
        if(productDTOPageData.getTotal()!=0){
            for(ProductDTO productDTO:productDTOPageData.getList()){
                String productType = productTypeService.selectById(productDTO.getProductTypeId()).getName();
                productDTO.setProductType(productType);
            }
        }
        return productDTOPageData;
    }

    @Override
    public ProductDTO get(Long id) {
        Product entity = baseDao.selectById(id);
        return ConvertUtils.sourceToTarget(entity, ProductDTO.class);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void save(ProductDTO dto) {
        Product entity = ConvertUtils.sourceToTarget(dto, Product.class);
        insert(entity);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void update(ProductDTO dto) {
        Product entity = ConvertUtils.sourceToTarget(dto, Product.class);
        updateById(entity);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean changeStatus(Long id) {
        //改变状态 开启1 关闭0
        Product entity = baseDao.selectById(id);
        Integer status = 1 - entity.getStatus();
        entity.setStatus(status);
        return updateById(entity);
    }

}