package com.cnbm.basic.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.cnbm.basic.dto.WorkingProcedureDTO;
import com.cnbm.basic.entity.WorkingProcedure;
import com.cnbm.basic.mapper.ProductMapper;
import com.cnbm.common.page.PageData;
import com.cnbm.common.service.impl.CrudServiceImpl;
import com.cnbm.basic.dto.ProductWorkingprocedureRelationDTO;
import com.cnbm.basic.mapper.ProductWorkingprocedureRelationMapper;
import com.cnbm.basic.entity.ProductWorkingprocedureRelation;
import com.cnbm.basic.service.IProductWorkingprocedureRelationService;
import com.cnbm.common.utils.ConvertUtils;
import com.cnbm.common.validator.ValidatorUtils;
import com.cnbm.common.validator.group.AddGroup;
import com.cnbm.common.validator.group.DefaultGroup;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * 工序 表
 *
 * @author why
 * @since 2022-07-15
 */
@Service
public class ProductWorkingprocedureRelationServiceImpl extends CrudServiceImpl<ProductWorkingprocedureRelationMapper, ProductWorkingprocedureRelation, ProductWorkingprocedureRelationDTO> implements IProductWorkingprocedureRelationService {

    @Override
    public QueryWrapper<ProductWorkingprocedureRelation> getWrapper(Map<String, Object> params){
        String id = (String)params.get("id");

        QueryWrapper<ProductWorkingprocedureRelation> wrapper = new QueryWrapper<>();
        wrapper.eq(StringUtils.isNotBlank(id), "id", id);

        return wrapper;
    }

    @Override
    public PageData<ProductWorkingprocedureRelationDTO> page (Map<String, Object> params){
        IPage<ProductWorkingprocedureRelation> page = baseDao.selectPage(
                getPage(params, "id", true),
                getWrapper(params)
        );
        return getPageData(page, ProductWorkingprocedureRelationDTO.class);
    }

    @Override
    public ProductWorkingprocedureRelationDTO get(Long id) {
        ProductWorkingprocedureRelation entity = baseDao.selectById(id);
        return ConvertUtils.sourceToTarget(entity, ProductWorkingprocedureRelationDTO.class);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void save(ProductWorkingprocedureRelationDTO dto) {
        ProductWorkingprocedureRelation entity = ConvertUtils.sourceToTarget(dto, ProductWorkingprocedureRelation.class);
        insert(entity);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void update(ProductWorkingprocedureRelationDTO dto) {
        ProductWorkingprocedureRelation entity = ConvertUtils.sourceToTarget(dto, ProductWorkingprocedureRelation.class);
        updateById(entity);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void delete(Long[] ids) {
        //删除
        deleteBatchIds(Arrays.asList(ids));
    }

    @Autowired
    private WorkingProcedureServiceImpl workingProcedureServiceImpl;

    @Override
    public List<ProductWorkingprocedureRelationDTO> getWorkingprocedureByProductId(Long productId){
        QueryWrapper<ProductWorkingprocedureRelation> wrapper = new QueryWrapper<>();
        wrapper.eq(ObjectUtils.isNotNull(productId), "product_id", productId);
        List<ProductWorkingprocedureRelation> relationList = baseDao.selectList(wrapper);
        List<ProductWorkingprocedureRelationDTO> dtoList = ConvertUtils.sourceToTarget(relationList, ProductWorkingprocedureRelationDTO.class);
        //设置工序名称
        for (ProductWorkingprocedureRelationDTO dto:dtoList){
            String workingProcedureName = workingProcedureServiceImpl.selectById(dto.getWorkingProcedureId()).getName();
            dto.setWorkingProcedureName(workingProcedureName);
        }
        return dtoList;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void batchInsertWorkingprocedure(ProductWorkingprocedureRelationDTO[] lists) {
        for(ProductWorkingprocedureRelationDTO dto:lists){
            ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);
            save(dto);
        }
    }

}