package com.cnbm.basic.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.cnbm.common.page.PageData;
import com.cnbm.common.service.impl.CrudServiceImpl;
import com.cnbm.basic.dto.UnitDTO;
import com.cnbm.basic.entity.Unit;
import com.cnbm.basic.mapper.UnitMapper;
import com.cnbm.basic.service.IUnitService;
import com.cnbm.common.utils.ConvertUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.Map;

/**
 * 单位 表
 *
 * @author why
 * @since 2022-06-30
 */
@Service
public class UnitServiceImpl extends CrudServiceImpl<UnitMapper, Unit, UnitDTO> implements IUnitService {

    @Override
    public QueryWrapper<Unit> getWrapper(Map<String, Object> params){

        QueryWrapper<Unit> wrapper = new QueryWrapper<>();
        wrapper.eq(ObjectUtils.isNotNull(params.get("status")), "status", params.get("status"));

        return wrapper;
    }

    @Override
    public PageData<UnitDTO> page (Map<String, Object> params){
        IPage<Unit> page = baseDao.selectPage(
                getPage(params, "id", true),
                getWrapper(params)
        );
        return getPageData(page, UnitDTO.class);
    }

    @Override
    public UnitDTO get(Long id) {
        Unit entity = baseDao.selectById(id);
        return ConvertUtils.sourceToTarget(entity, UnitDTO.class);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void save(UnitDTO dto) {
        Unit entity = ConvertUtils.sourceToTarget(dto, Unit.class);
        insert(entity);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void update(UnitDTO dto) {
        Unit entity = ConvertUtils.sourceToTarget(dto, Unit.class);
        updateById(entity);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void changeStatus(Long id) {
        //改变状态 开启1 关闭0
        Unit entity = baseDao.selectById(id);
        Integer status = 1 - entity.getStatus();
        entity.setStatus(status);
        updateById(entity);
    }
}